(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6720],{66541:(e,t,o)=>{"use strict";o.r(t),o.d(t,{default:()=>c});var a=o(56901),n=o(52430),r=o(84709),l=o(20850),s=o(19915),i=o(36735);const c=[{id:"@retrolab/tree-extension:buttons",requires:[n.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:n}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-notebook";n.addCommand(i,{label:l.__("New Notebook"),icon:s.notebookIcon,execute:()=>n.execute("notebook:create-new")});const c=new a.CommandToolbarButton({commands:n,id:i}),d=new a.CommandToolbarButton({commands:n,id:"filebrowser:create-new-file"});r.toolbar.insertItem(0,"new-notebook",c),r.toolbar.insertItem(1,"new-file",d)}},{id:"@retrolab/tree-extension:new-console",requires:[n.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:n}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-console";n.addCommand(i,{label:l.__("New Console"),icon:s.consoleIcon,execute:()=>n.execute("console:create")});const c=new a.CommandToolbarButton({commands:n,id:i});r.toolbar.insertItem(2,"new-console",c)}},{id:"@retrolab/tree-extension:new-terminal",requires:[n.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:n}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-terminal";n.addCommand(i,{label:l.__("New Terminal"),icon:s.terminalIcon,execute:()=>n.execute("terminal:create-new")});const c=new a.CommandToolbarButton({commands:n,id:i});r.toolbar.insertItem(3,"new-terminal",c)}},{id:"@jupyterlab-classic/tree-extension:widget",requires:[n.IFileBrowserFactory,l.ITranslator],optional:[r.IRunningSessionManagers],autoStart:!0,activate:(e,t,o,a)=>{const n=new i.TabPanel({tabPlacement:"top",tabsMovable:!0});n.addClass("jp-TreePanel");const l=o.load("retrolab"),{defaultBrowser:c}=t;if(c.title.label=l.__("Files"),n.addWidget(c),n.tabBar.addTab(c.title),a){const e=new r.RunningSessions(a,o);e.id="jp-running-sessions",e.title.label=l.__("Running"),e.title.icon=s.runningIcon,n.addWidget(e),n.tabBar.addTab(e.title)}e.shell.add(n,"main",{rank:100})}}]}}]);